// Non-swing version.
import java.applet.*;
import java.awt.*;
import java.awt.event.*;
import java.text.*;     // for DecimalFormat class

/** GPACalc.java.
    Computes GPA needed for Off-Campus Study.
    Allows user to: <br>
    a) Compute projected GPA, <br>
    b) Compute minimum GPA needed this semester to reach 2.7 GPA overall.
 */
public class GPACalc2 extends Applet
                implements ActionListener, ItemListener{

    private TextField creditsTF, creditsThisSemesterTF, 
            currentGPAtf, anticipatedGPAtf, projectedGPAtf, neededGPAtf;
            
    private Label GPAthisSemesterLabel, projectedGPAlabel, anticipatedGPAlabel, neededGPAlabel;
    
    private Checkbox computeProjectedGPAradioButton, 
                         computeNeededGPAradioButton;

    private CheckboxGroup group;
    
    private Button computeButton, moreInfoButton;
    
    /** Constructs the instance variables and determines their roles in the 
        applet, sets the listeners, and creates the layout. 
     */
    public void init(){
        // Text fields. 
        creditsTF = new TextField("");
        creditsThisSemesterTF  = new TextField("4");
        currentGPAtf = new TextField("");
        projectedGPAtf = new TextField("");
        anticipatedGPAtf = new TextField("");
        projectedGPAtf.setEditable(false);
        neededGPAtf = new TextField("");
        neededGPAtf.setEditable(false);

        // Labels
        projectedGPAlabel = new Label("Projected GPA  ", Label.RIGHT);
        anticipatedGPAlabel = new Label("Enter anticipated GPA this semester  ", Label.RIGHT);
        neededGPAlabel = new Label("Minimum GPA needed this semester  ", Label.RIGHT);
        neededGPAlabel.setForeground(Color.lightGray);

        // Radio buttons and button group.
        group = new CheckboxGroup();
        computeProjectedGPAradioButton = new Checkbox("Compute projected GPA", group, true);
        computeNeededGPAradioButton = new Checkbox("Compute needed GPA", group, false);

        computeButton = new Button("Compute");
        moreInfoButton = new Button("More Info");

        // Add listeners.
        computeButton.addActionListener(this);
        moreInfoButton.addActionListener(this);
        computeProjectedGPAradioButton.addItemListener(this);
        computeNeededGPAradioButton.addItemListener(this);

        setLayout();

    } // end of init method

    ///////////////////////////////////////////////////////////
        
    /** Opens textfields to allow data entry based on which radio 
        button has been selecteded. Triggered by the radio buttons. */
    public void itemStateChanged(ItemEvent e){
        if (e.getSource() == computeProjectedGPAradioButton){
            anticipatedGPAtf.setEditable(true);
            anticipatedGPAlabel.setForeground(Color.black);
            projectedGPAlabel.setForeground(Color.black);
            neededGPAlabel.setForeground(Color.lightGray);
            neededGPAtf.setText("");
        }
        else{ // selected computeNeedededGPAradioButton
            anticipatedGPAlabel.setForeground(Color.lightGray);
            anticipatedGPAtf.setEditable(false);
            anticipatedGPAtf.setText("");
            projectedGPAtf.setText("");
            projectedGPAlabel.setForeground(Color.lightGray);
            neededGPAlabel.setForeground(Color.black);
        }
    } // end of itemStateChanged method
    
    /////////////////////////////////////////////////////////////////

    /** Performs computation based on which radio button has been 
        selected. Triggered by compute button. */
    public void actionPerformed( ActionEvent event ){
        
        if (event.getSource() == computeButton){

            double currentGPA = Double.parseDouble(currentGPAtf.getText());
            double credits = Double.parseDouble(creditsTF.getText());
            double creditsNow = Double.parseDouble(creditsThisSemesterTF.getText());
            DecimalFormat df = new DecimalFormat("0.00");

          //  if (group.getSelection() == computeProjectedGPAradioButton){  Why doesn't this work?
            if (computeProjectedGPAradioButton.getState()){
                double anticipatedGPA = Double.parseDouble(anticipatedGPAtf.getText());
                double projectedGPA = (currentGPA*credits + anticipatedGPA*creditsNow)/(credits + creditsNow);
                projectedGPAtf.setText(df.format(projectedGPA));
            }
            else{  // selected radio button is computeNeededGPAradioButton
                double neededGPA = (2.7*(credits + creditsNow) - currentGPA*credits)/creditsNow;
                neededGPAtf.setText(df.format(neededGPA));
            }
        }

        if (event.getSource() == moreInfoButton){
//             String message = "Enter the number of courses you have completed "
//                 + "at Wabash. \nInclude failed courses.  Include retaken courses only once.";
//             OptionPane.showMessageDialog(null,message);
        }

    } // end of actionPerformed method

    /////////////////////////////////////////////////////////////////

    // Sets the layout of the applet.
    private void setLayout(){
        ////////////// Create panels /////////////////////////
        // Io panel 
        Panel ioPanel = new Panel(new GridLayout(8,2));
        ioPanel.setBackground(Color.white);
        ioPanel.add(new Label("Enter current GPA  ", Label.RIGHT));
        ioPanel.add(currentGPAtf);
        ioPanel.add(new Label("Enter number of Wabash courses completed  ", Label.RIGHT));
            Panel tempPanel = new Panel(new GridLayout(1,2));
            tempPanel.add(creditsTF); tempPanel.add(moreInfoButton);
        ioPanel.add(tempPanel);
        ioPanel.add(new Label("Enter number of courses this semester  ", 
                                    Label.RIGHT));
        ioPanel.add(creditsThisSemesterTF);
        ioPanel.add(new Label("Select computation method  ", 
                                    Label.RIGHT));

        // RadioButton panel contains the two radio buttons.
        Panel radioButtonPanel = new Panel(new GridLayout(2,1));
        radioButtonPanel.add(computeProjectedGPAradioButton);
        radioButtonPanel.add(computeNeededGPAradioButton);
        
        ioPanel.add(radioButtonPanel);
        ioPanel.add(anticipatedGPAlabel);
        ioPanel.add((anticipatedGPAtf));
        
        ioPanel.add(new Label("Click compute button ==>  ", 
                                    Label.RIGHT));
        ioPanel.add(computeButton);

        ioPanel.add(projectedGPAlabel);
        ioPanel.add((projectedGPAtf));
        ioPanel.add(neededGPAlabel);
        ioPanel.add((neededGPAtf));

        /////////////////////////////////////////////////////////////

        // Finally, put it all together in the content pane.
//         Container window = getContentPane();
//         window.setBackground(Color.red);
//         window.setLayout(new BorderLayout());       
//         window.add(BorderLayout.NORTH,
//             new Label("Wabash Off-Campus Study GPA Calculator", Label.CENTER));
//         window.add(BorderLayout.CENTER, ioPanel);
//         String message = "WARNING: If you are retaking a course this semester, this calculation will not be accurate!";
//         window.add(BorderLayout.SOUTH, new Label(message, Label.CENTER));

        setBackground(Color.red);
        setLayout(new BorderLayout());       
        add(BorderLayout.NORTH,
            new Label("Wabash Off-Campus Study GPA Calculator", Label.CENTER));
        add(BorderLayout.CENTER, ioPanel);
        String message = "WARNING: If you are retaking a course this semester, this calculation will not be accurate!";
        add(BorderLayout.SOUTH, new Label(message, Label.CENTER));

    } // end setLayout method
    
}
